@@ -64,6 +64,7 @@ G_MODULE_EXPORT void font_set_cb (GtkFontButton * fb, Totem * totem);
 G_MODULE_EXPORT void encoding_set_cb (GtkComboBox *cb, Totem *totem);
 G_MODULE_EXPORT void font_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
 G_MODULE_EXPORT void encoding_changed_cb (GConfClient *client, guint cnxn_id, GConfEntry *entry, Totem *totem);
+G_MODULE_EXPORT void auto_chapters_toggled_cb (GtkToggleButton *togglebutton, Totem *totem);
 
 static void
 totem_action_info (char *reason, Totem *totem)
@@ -354,6 +355,23 @@ autoload_subtitles_changed_cb (GConfClient *client, guint cnxn_id,
 			G_CALLBACK (checkbutton3_toggled_cb), totem);
 }
 
+static void
+autoload_chapters_changed_cb (GConfClient *client, guint cnxn_id,
+			      GConfEntry *entry, Totem *totem)
+{
+	GObject *item;
+
+	item = gtk_builder_get_object (totem->xml, "tpw_auto_chapters_checkbutton");
+	g_signal_handlers_disconnect_by_func (item,
+					      auto_chapters_toggled_cb, totem);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item),
+				      gconf_client_get_bool (totem->gc, GCONF_PREFIX"/autoload_chapters", NULL));
+
+	g_signal_connect (item, "toggled",
+			  G_CALLBACK (auto_chapters_toggled_cb), totem);
+}
+
 void
 connection_combobox_changed (GtkComboBox *combobox, Totem *totem)
 {
@@ -523,11 +541,21 @@ encoding_changed_cb (GConfClient *client, guint cnxn_id,
 	bacon_video_widget_set_subtitle_encoding (totem->bvw, encoding);
 }
 
+void
+auto_chapters_toggled_cb (GtkToggleButton *togglebutton, Totem *totem)
+{
+	gboolean value;
+
+	value = gtk_toggle_button_get_active (togglebutton);
+
+	gconf_client_set_bool (totem->gc, GCONF_PREFIX"/autoload_chapters", value, NULL);
+}
+
 void
 totem_setup_preferences (Totem *totem)
 {
 	GtkWidget *menu, *content_area;
-	gboolean show_visuals, auto_resize, is_local, no_deinterlace, lock_screensaver_on_audio;
+	gboolean show_visuals, auto_resize, is_local, no_deinterlace, lock_screensaver_on_audio, auto_chapters;
 	int connection_speed;
 	guint i, hidden;
 	char *visual, *font, *encoding;
@@ -568,7 +596,6 @@ totem_setup_preferences (Totem *totem)
 			GTK_STOCK_CLOSE,
 			GTK_RESPONSE_ACCEPT,
 			NULL);
-	gtk_dialog_set_has_separator (GTK_DIALOG (totem->prefs), FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (totem->prefs), 5);
 	content_area = gtk_dialog_get_content_area (GTK_DIALOG (totem->prefs));
 	gtk_box_set_spacing (GTK_BOX (content_area), 2);
@@ -658,6 +685,19 @@ totem_setup_preferences (Totem *totem)
 				 (GConfClientNotifyFunc) autoload_subtitles_changed_cb,
 				 totem, NULL, NULL);
 
+	/* Auto-load external chapters */
+	item = gtk_builder_get_object (totem->xml, "tpw_auto_chapters_checkbutton");
+	auto_chapters = gconf_client_get_bool (totem->gc,
+					       GCONF_PREFIX"/autoload_chapters", NULL);
+
+	g_signal_handlers_disconnect_by_func (item, auto_chapters_toggled_cb, totem);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (item), auto_chapters);
+	g_signal_connect (item, "toggled", G_CALLBACK (auto_chapters_toggled_cb), totem);
+
+	gconf_client_notify_add (totem->gc, GCONF_PREFIX"/autoload_chapters",
+				 (GConfClientNotifyFunc) autoload_chapters_changed_cb,
+				 totem, NULL, NULL);
+
 	/* Visuals list */
 	list = bacon_video_widget_get_visuals_list (totem->bvw);
 	menu = gtk_menu_new ();
